.. _nifty_api_reference:

Inferno API Reference
============================


.. autosummary::
    :toctree: gen_modules/
    
    :template: template_module.rst
    
    inferno
    inferno.extensions
    inferno.extensions.containers
    inferno.extensions.criteria
    inferno.extensions.initializers
    inferno.extensions.layers
    inferno.extensions.metrics
    inferno.extensions.optimizers
    inferno.io
    inferno.utils
    inferno.trainers
    inferno.trainers.callbacks
    inferno.trainers.callbacks.logging